import prisma from "../lib/prisma";
import { getServerSession } from "next-auth/next";
import { authOptions } from "../pages/api/auth/[...nextauth]";

import hasAccess from "../utilities/hasAccess";
import { isInFuture } from '../utilities/dates';

export const resolvers = {
  Query: {
    getEvents: async () => {
      const events = await prisma.event.findMany();
      return events;
    },
    getFutureEvents: async (_, data, { session }) => {
      const events = await prisma.event.findMany({
        include: {
          signUps: {
            select: {
              sub: true,
              firstName: hasAccess(session, true),
              lastName: hasAccess(session, true),
              email: hasAccess(session, true)
            }
          },
        }
      });
      const futureEvents = events.filter((event) => isInFuture(event));
      return futureEvents;
    },
  },
  Mutation: {
    addEvent: async (_, data, { session }) => {
      if (!hasAccess(session, true)) return false;

      const {time, ...dataWithoutTime} = data;
      const event = await prisma.event.create({
        data: {
          ...dataWithoutTime,
          startTime: data.time[0],
          endTime: data.time[1]
        },
      });
      return event ? true : false;
    },
    editEvent: async (_, data, { session }) => {
      if (!hasAccess(session, true)) return false;

      const {time, ...dataWithoutTime} = data;
      const event = await prisma.event.update({
        where: { id: data.id },
        data: {
          ...dataWithoutTime,
          startTime: data.time[0],
          endTime: data.time[1]
        },
      });
      return event ? true : false;
    },
    addSignUp: async(_, { id }, { session }) => {
      if(!hasAccess(session, false)) return false;

      const signUp = await prisma.signUp.create({
        data: {
          eventId: id,
          sub: session.info.payload.sub,
          firstName: session.info.payload.given_name,
          lastName: session.info.payload.family_name,
          email: session.info.payload.email
        }
      });

      return signUp ? true : false;
    },
    removeSignUp: async(_, { id }, { session }) => {
      if(!hasAccess(session, false)) return false;

      const signUp = await prisma.signUp.findMany({
        where: {
          eventId: id,
          sub: session.info.payload.sub
        }
      });

      if(signUp.length == 0) return false;

      await prisma.signUp.delete({
        where: {
          id: signUp[0].id
        }
      });

      return true;
    }
  },
};
